<?php

namespace Shopping\Product\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Shopping\Product\Http\Requests\AttributegroupRequest;
use Shopping\Product\Interfaces\AttributegroupRepositoryInterface;
use Shopping\Product\Models\Attributegroup;

/**
 * Resource controller class for attributegroup.
 */
class AttributegroupResourceController extends BaseController
{

    /**
     * Initialize attributegroup resource controller.
     *
     * @param type AttributegroupRepositoryInterface $attributegroup
     *
     * @return null
     */
    public function __construct(AttributegroupRepositoryInterface $attributegroup)
    {
        parent::__construct();
        $this->repository = $attributegroup;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Shopping\Product\Repositories\Criteria\AttributegroupResourceCriteria::class);
    }

    /**
     * Display a list of attributegroup.
     *
     * @return Response
     */
    public function index(AttributegroupRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Shopping\Product\Repositories\Presenter\AttributegroupPresenter::class)
                ->$function();
        }

        $attributegroups = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('product::attributegroup.names'))
            ->view('product::attributegroup.index', true)
            ->data(compact('attributegroups', 'view'))
            ->output();
    }

    /**
     * Display attributegroup.
     *
     * @param Request $request
     * @param Model   $attributegroup
     *
     * @return Response
     */
    public function show(AttributegroupRequest $request, Attributegroup $attributegroup)
    {

        if ($attributegroup->exists) {
            $view = 'product::attributegroup.show';
        } else {
            $view = 'product::attributegroup.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('product::attributegroup.name'))
            ->data(compact('attributegroup'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new attributegroup.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AttributegroupRequest $request)
    {

        $attributegroup = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('product::attributegroup.name')) 
            ->view('product::attributegroup.create', true) 
            ->data(compact('attributegroup'))
            ->output();
    }

    /**
     * Create new attributegroup.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AttributegroupRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $attributegroup                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('product::attributegroup.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('product/attributegroup/' . $attributegroup->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/product/attributegroup'))
                ->redirect();
        }

    }

    /**
     * Show attributegroup for editing.
     *
     * @param Request $request
     * @param Model   $attributegroup
     *
     * @return Response
     */
    public function edit(AttributegroupRequest $request, Attributegroup $attributegroup)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('product::attributegroup.name'))
            ->view('product::attributegroup.edit', true)
            ->data(compact('attributegroup'))
            ->output();
    }

    /**
     * Update the attributegroup.
     *
     * @param Request $request
     * @param Model   $attributegroup
     *
     * @return Response
     */
    public function update(AttributegroupRequest $request, Attributegroup $attributegroup)
    {
        try {
            $attributes = $request->all();

            $attributegroup->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('product::attributegroup.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('product/attributegroup/' . $attributegroup->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('product/attributegroup/' . $attributegroup->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the attributegroup.
     *
     * @param Model   $attributegroup
     *
     * @return Response
     */
    public function destroy(AttributegroupRequest $request, Attributegroup $attributegroup)
    {
        try {

            $attributegroup->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('product::attributegroup.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('product/attributegroup/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('product/attributegroup/' . $attributegroup->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple attributegroup.
     *
     * @param Model   $attributegroup
     *
     * @return Response
     */
    public function delete(AttributegroupRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('product::attributegroup.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('product/attributegroup'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/product/attributegroup'))
                ->redirect();
        }

    }

    /**
     * Restore deleted attributegroups.
     *
     * @param Model   $attributegroup
     *
     * @return Response
     */
    public function restore(AttributegroupRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('product::attributegroup.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/product/attributegroup'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/product/attributegroup/'))
                ->redirect();
        }

    }

}
